@@ -47,7 +47,6 @@
 #include <libedata-book/e-book-backend-summary.h>
 #include "e-book-backend-mapi.h"
 
-
 static EBookBackendClass *e_book_backend_mapi_parent_class;
 static gboolean enable_debug = TRUE;
 
@@ -103,9 +102,9 @@ static const struct field_element_mapping {
 	{ E_CONTACT_FAMILY_NAME, PT_STRING8, PR_SURNAME , ELEMENT_TYPE_SIMPLE},
 	{ E_CONTACT_NICKNAME, PT_STRING8, PR_NICKNAME, ELEMENT_TYPE_SIMPLE },
 
-	{ E_CONTACT_EMAIL_1, PT_STRING8, PROP_TAG(PT_UNICODE, 0x8084), ELEMENT_TYPE_SIMPLE},
-	{ E_CONTACT_EMAIL_2, PT_STRING8, PROP_TAG(PT_UNICODE, 0x8094), ELEMENT_TYPE_SIMPLE},
-	{ E_CONTACT_EMAIL_3, PT_STRING8, PROP_TAG(PT_UNICODE, 0x80a4), ELEMENT_TYPE_SIMPLE},
+	{ E_CONTACT_EMAIL_1, PT_STRING8, PROP_TAG(PT_STRING8, 0x8084), ELEMENT_TYPE_SIMPLE},
+	{ E_CONTACT_EMAIL_2, PT_STRING8, PROP_TAG(PT_STRING8, 0x8093), ELEMENT_TYPE_SIMPLE},
+	{ E_CONTACT_EMAIL_3, PT_STRING8, PROP_TAG(PT_STRING8, 0x80a3), ELEMENT_TYPE_SIMPLE},
 	{ E_CONTACT_IM_AIM,  PT_STRING8, PROP_TAG(PT_UNICODE, 0x8062), ELEMENT_TYPE_COMPLEX},	
 		
 	{ E_CONTACT_PHONE_BUSINESS, PT_STRING8, PR_OFFICE_TELEPHONE_NUMBER, ELEMENT_TYPE_SIMPLE},
@@ -1198,7 +1197,7 @@ book_view_thread (gpointer data)
 	if (enable_debug)
 		printf("mapi: book view\n");
 	
-	bonobo_object_ref (book_view);
+	g_object_ref (book_view);
 	e_flag_set (closure->running);
 						
 	e_data_book_view_notify_status_message (book_view, "Searching...");
@@ -1210,7 +1209,7 @@ book_view_thread (gpointer data)
 		if (!priv->marked_for_offline) {
 			e_data_book_view_notify_complete (book_view, 
 					GNOME_Evolution_Addressbook_OfflineUnavailable);
-			bonobo_object_unref (book_view);
+			g_object_unref (book_view);
 			return;
 		}
 		if (!priv->cache) {
@@ -1229,7 +1228,7 @@ book_view_thread (gpointer data)
 				get_contacts_from_cache (backend, query, ids, book_view, closure);
 				g_ptr_array_free (ids, TRUE);
 			}
-			bonobo_object_unref (book_view);
+			g_object_unref (book_view);
 			return;
 		}
 
@@ -1255,7 +1254,7 @@ book_view_thread (gpointer data)
 							  GNOME_Evolution_Addressbook_Success);
 		if (temp_list)
 			 g_list_free (temp_list);
-		bonobo_object_unref (book_view);
+		g_object_unref (book_view);
 		return;
 		
 	case GNOME_Evolution_Addressbook_MODE_REMOTE:
@@ -1264,7 +1263,7 @@ book_view_thread (gpointer data)
 			e_book_backend_notify_auth_required (E_BOOK_BACKEND (backend));
 			e_data_book_view_notify_complete (book_view,
 						GNOME_Evolution_Addressbook_AuthenticationRequired);
-			bonobo_object_unref (book_view);
+			g_object_unref (book_view);
 			return;
 		}
 		
@@ -1279,7 +1278,7 @@ book_view_thread (gpointer data)
 					get_contacts_from_cache (backend, query, ids, book_view, closure);
 					g_ptr_array_free (ids, TRUE);
 				}
-				bonobo_object_unref (book_view);
+				g_object_unref (book_view);
 				return;
 			}
 			
@@ -1304,7 +1303,7 @@ book_view_thread (gpointer data)
 								  GNOME_Evolution_Addressbook_Success);
 			if (temp_list)
 				 g_list_free (temp_list);
-			bonobo_object_unref (book_view);
+			g_object_unref (book_view);
 			return;
 		}
 		
@@ -1326,7 +1325,7 @@ book_view_thread (gpointer data)
         	                if (e_flag_is_set (closure->running))
                 	                e_data_book_view_notify_complete (book_view, 
                         	                                          GNOME_Evolution_Addressbook_OtherError);      
-	                        bonobo_object_unref (book_view);
+	                        g_object_unref (book_view);
 					
 				if (or_res)
 					g_free(or_res);
@@ -1342,7 +1341,7 @@ book_view_thread (gpointer data)
 				if (e_flag_is_set (closure->running))
 					e_data_book_view_notify_complete (book_view, 
 									  GNOME_Evolution_Addressbook_OtherError);      
-				bonobo_object_unref (book_view);
+				g_object_unref (book_view);
 				return;
 			}
 		}
@@ -1350,7 +1349,7 @@ book_view_thread (gpointer data)
 		if (e_flag_is_set (closure->running))
 			e_data_book_view_notify_complete (book_view,
 							  GNOME_Evolution_Addressbook_Success);
-		bonobo_object_unref (book_view);
+		g_object_unref (book_view);
 
 		
 
